=======
Credits
=======

Development Lead
----------------

* Jan Petter Maehlen <jepe@ife.no>
* Muhammad Abdelhamid <muhammad.abdelhamid@ife.no>
* Asbjoern Ulvestad <asbjorn.ulvestad@ife.no>


Contributors
------------

* Tor Kristian Vara <tor.vara@nmbu.no>
* Ulrik Aalborg Eriksen <ulrikaer@stud.ntnu.no>
* Julia Wind <julia.wind@ife.no>
* Carl Erik Lie Foss <carl.foss@ife.no>
* Amund Midtgard Raniseth <amund.raniseth@gmail.com>

